# TOPSIS

Author: **Aarushi Abrol**.

Type: **Package**.

Title: **TOPSIS method for multiple-criteria decision making (MCDM)**.

Version: **1.1.1**

Date: **2022-1-22**

Maintainer: **Aarushi Abrol <aabrol_be20@thapar.edu>**.

Description: **Evaluation of alternatives based on multiple criteria using TOPSIS method.**.

---

## What is TOPSIS?

**T**echnique for **O**rder **P**reference by **S**imilarity to **I**deal **S**olution
(TOPSIS) originated in the 1980s as a multi-criteria decision making method.
TOPSIS chooses the alternative of shortest Euclidean distance from the ideal solution,
and greatest distance from the negative-ideal solution.

<br>

## License
© 2022 Aarushi Abrol

This repository is licensed under the MIT license. See LICENSE for details.


